#
# spec file for package gap-xmod
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-xmod
Version:        2.93
Release:        1.1
Summary:        GAP: Crossed Modules and Cat1-Groups
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/xmod/
#Git-Clone:     https://github.com/gap-packages/xmod
Source:         https://github.com/gap-packages/xmod/releases/download/v%version/XMod-%version.tar.gz
BuildArch:      noarch
BuildRequires:  gap-rpm-devel
Requires:       gap-autpgrp >= 1.10.2
Requires:       gap-core >= 4.11
Requires:       gap-groupoids >= 1.73
Requires:       gap-hap >= 1.29
Requires:       gap-smallgrp >= 1.4.2
Requires:       gap-utils >= 0.81

%description
The XMod package provides a collection of functions for computing
with crossed modules and cat1-groups, their derivations and sections,
morphisms of these structures, and higher-dimensional
generalisations.

%prep
%autosetup -n XMod-%version

%build

%install
%gappkg_simple_install

%files -f %name.files

%changelog
* Mon Apr 28 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.93
  * Added sub-crossed square and sub-cat2-group operations
  * Simplified the construction of crossed pairings so that
    files map2arg.{gd,gi} can be removed
  * Implemented (Inner)ActorCat1Group
  * Added AutomorphismPermGroup method for cat1-groups
  * Renamed PermAutomorphismAsXModMorphism as
    PermAutomorphismAs2dGroupMorphism and added cat1-group method
  * Added WhiteheadRegularGroup and WhiteheadGroupIsomorphism
  * Removed the unused CompositeDerivation (= WhiteheadProduct)
  * Removed the unused (List)InverseDerivations
  * Renamed WhiteheadGroupGeneratingDerivations as ...UpMappings
  * Added WhiteheadGroupInverseIsomorphism
* Tue Jan 23 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.92
  * Added methods for WhiteheadXMod etc. for xmods which are not
    permanent xmods
  * Now using the NC version of PreImagesRepresentative
* Sun Jun 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.91
  * added a chapter on double groupoids with operations
    EnhancedBasicDoubleGroupoid, DoubleGroupooidWithZeroBoundary
  * added PreXModWithTrivialRange
* Sat Feb 11 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.89
  * added RegularActionHomomorphism(Object/2DimensionalGroup)
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.88
  * Lots of new and renamed functions
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 2.6.4
  * fixed tests to work with both 4r8 and dev in 3 options
  * removed attribute AutoGroup (=Range(XModAction)) for xmods
  * added operations SinglePiecePreXModWithObjects(NC)
  * added Root2dGroup for prexmods with objects
  * ImageElmXModAction now works for xmods of groupoids
  * added operation ImageElmXModAction
  * renamed test files and made them independent
* Fri Sep  8 2017 jengelh@inai.de
- Update to new upstream release 2.62
  * Replaced PreXModIsomorphismByIsomorphisms by the more general
    IsomorphismByIsomorphisms; then functions such as
    IsomorphismPerm2DimensionalGroup rewritten to use it.
  * Added IsomorphismByIsomorphisms for pre1-cat-groups
  * New functions added for crossed square <-> cat2-group:
    ConjugationActionForCrossedSquare;
    ElementsRelationsForSemidirectProduct
  * Added CoproductInfo for coproducts FactorXMod now
    FactorPreXMod (ditto NaturalMorphisms)
  * Added Is2dGroupMorphismData and modified construction
    functions Method for IsNormal now applies to precrossed
    modules added PeifferSub2dGroup
  * Added operation DiagonalCat1 and example S3xS3 => S3
  * Added operation CoproductXMod and files `coprod.g`,
    `coprod.tst`
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 2.59
  * added property IsEndomorphismPreCat1
  * modified IsomorphismPerm2dGroup for PreCat1 objects
* Mon Nov 21 2016 jengelh@inai.de
- Update to new upstream release 2.58
  * added files hap.gd, hap.gi
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 2.56
  * remove functions from util.g(d/i) now in Utils; require Utils
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 2.51
  * renamed Rank and MiddleLength and now for p-groups only
  * XPair -> XPairing, etc.
  * IsomorphismPermPre(XMod/Cat1) -> IsomorphismPerm2dGroup, etc.
  * IsStemGroup & IsStemXMod -> IsStemDomain etc.
  * RestrictionMappingGroups -> GeneralRestgrictedMapping
  * CentralQuotient now a crossed module or a crossed square
  * added LeftRightMorphism and UpDownMorphism for crossed squares
  * methods for InnerMorphism, ActorXMod, CentreXMod, etc.
  now specified only for permutation crossed modules
* Tue Dec  8 2015 jengelh@inai.de
- Update to new upstream release 2.44
  * added Centralizer and Normalizer methods for crossed modules
  * added ExternalSetXMod
  * added operation Displacement
  * added AllStemGroupFamilies and Set various Names
  * added NaturalHomomorphismByNormalSubXMod
  * added CrossActionSubgroup
* Sun Feb 22 2015 jengelh@inai.de
- Update to new upstream release 2.31
  * Metadata update (homepage URL) only
* Fri Feb  7 2014 jengelh@inai.de
- Update to new upstream release 2.26
  * minor mod to WhiteheadTransMonoid to fix gp2up.tst output
  * fixed errors in cat1data.g reported by Van Luyen Le.
  * fixed error in Cat1MorphismByXModMorphism.
  * completed work on groups of order [64..70] in cat1data.g
  * added operation CollectPartsAlreadyDone.
  * added operation PreCat1IsomorphismByIsomorphisms.
  * fixed bug in PermCat1Select sent by Van Luyen Le
  * put groups of order 64 back into cat1data.g
  * rewrite of testall.g following Alex K's wedderga example
* Fri May 10 2013 jengelh@inai.de
- Split xmod (version 2.22) off the gap RPM package
